==> mono-2.10.2.tar.bz2: mono-2.10.2/mcs/class/System/System.Collections.Generic/ISet.cs <==
//
// System.Collections.Generic.ISet.cs
//
// Author:
//   Miguel de Icaza (miguel@gnome.org)
//
// Copyright (C) 2009 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
#if NET_2_1 || NET_4_0

namespace System.Collections.Generic {
	public interface ISet<T> : ICollection<T>
	{
		new bool Add (T item);
		void ExceptWith (IEnumerable<T> other);
		void IntersectWith (IEnumerable<T> other);
		bool IsProperSubsetOf (IEnumerable<T> other);
		bool IsProperSupersetOf (IEnumerable<T> other);
		bool IsSubsetOf (IEnumerable<T> other);
		bool IsSupersetOf (IEnumerable<T> other);
		bool Overlaps (IEnumerable<T> other);
		bool SetEquals (IEnumerable<T> other);
		void SymmetricExceptWith (IEnumerable<T> other);
		void UnionWith (IEnumerable<T> other);
	}
}
#endif

==> mono-3.0.3.tar.bz2: mono-3.0.3/mcs/class/System/System.Collections.Generic/ISet.cs <==
//
// System.Collections.Generic.ISet.cs
//
// Author:
//   Miguel de Icaza (miguel@gnome.org)
//
// Copyright (C) 2009 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
#if NET_2_1 || MOBILE || NET_4_0

namespace System.Collections.Generic {
	public interface ISet<T> : ICollection<T>
	{
		new bool Add (T item);
		void ExceptWith (IEnumerable<T> other);
		void IntersectWith (IEnumerable<T> other);
		bool IsProperSubsetOf (IEnumerable<T> other);
		bool IsProperSupersetOf (IEnumerable<T> other);
		bool IsSubsetOf (IEnumerable<T> other);
		bool IsSupersetOf (IEnumerable<T> other);
		bool Overlaps (IEnumerable<T> other);
		bool SetEquals (IEnumerable<T> other);
		void SymmetricExceptWith (IEnumerable<T> other);
		void UnionWith (IEnumerable<T> other);
	}
}
#endif
